# Vibe Check Report

A vibe-check run across 12 of the most popular Python repositories.
Generated by [vibe-checker](https://github.com/fabiosousa/vibe-checker).

---

## Summary Table

| Repo | Files | Violations | Score | Verdict |
|------|------:|-----------:|------:|---------|
| [django](https://github.com/django/django) | 902 | 8801 | 51/100 | the vibes are questionable |
| [flask](https://github.com/pallets/flask) | 24 | 608 | 0/100 | it's giving dumpster fire |
| [fastapi](https://github.com/tiangolo/fastapi) | 48 | 1066 | 0/100 | it's giving dumpster fire |
| [pandas](https://github.com/pandas-dev/pandas) | 1414 | 56653 | 0/100 | expired |
| [scikit-learn](https://github.com/scikit-learn/scikit-learn) | 631 | 26277 | 0/100 | expired |
| [transformers](https://github.com/huggingface/transformers) | 2476 | 54012 | 0/100 | it's giving dumpster fire |
| [pip](https://github.com/pypa/pip) | 401 | 5907 | 26/100 | this is a cry for help |
| [ruff](https://github.com/astral-sh/ruff) | 14 | 136 | 51/100 | concerning |
| [pytest](https://github.com/pytest-dev/pytest) | 73 | 1734 | 0/100 | cooked |
| [bottle](https://github.com/bottlepy/bottle) | 30 | 1561 | 0/100 | expired |
| [requests](https://github.com/psf/requests) | 18 | 413 | 0/100 | it's giving dumpster fire |
| [rich](https://github.com/Textualize/rich) | 100 | 1552 | 22/100 | cooked |

---

## Web / APIs

### [django](https://github.com/django/django) — 51/100 · *the vibes are questionable*

- **Files scanned:** 902
- **Total violations:** 8801
- **Top rules triggered:** none

### [flask](https://github.com/pallets/flask) — 0/100 · *it's giving dumpster fire*

- **Files scanned:** 24
- **Total violations:** 608
- **Top rules triggered:** none

### [fastapi](https://github.com/tiangolo/fastapi) — 0/100 · *it's giving dumpster fire*

- **Files scanned:** 48
- **Total violations:** 1066
- **Top rules triggered:** none

---

## Data / ML

### [pandas](https://github.com/pandas-dev/pandas) — 0/100 · *expired*

- **Files scanned:** 1414
- **Total violations:** 56653
- **Top rules triggered:** none

### [scikit-learn](https://github.com/scikit-learn/scikit-learn) — 0/100 · *expired*

- **Files scanned:** 631
- **Total violations:** 26277
- **Top rules triggered:** none

### [transformers](https://github.com/huggingface/transformers) — 0/100 · *it's giving dumpster fire*

- **Files scanned:** 2476
- **Total violations:** 54012
- **Top rules triggered:** none

---

## Tooling

### [pip](https://github.com/pypa/pip) — 26/100 · *this is a cry for help*

- **Files scanned:** 401
- **Total violations:** 5907
- **Top rules triggered:** none

### [ruff](https://github.com/astral-sh/ruff) — 51/100 · *concerning*

- **Files scanned:** 14
- **Total violations:** 136
- **Top rules triggered:** none

### [pytest](https://github.com/pytest-dev/pytest) — 0/100 · *cooked*

- **Files scanned:** 73
- **Total violations:** 1734
- **Top rules triggered:** none

---

## Fun / Interesting

### [bottle](https://github.com/bottlepy/bottle) — 0/100 · *expired*

- **Files scanned:** 30
- **Total violations:** 1561
- **Top rules triggered:** none

### [requests](https://github.com/psf/requests) — 0/100 · *it's giving dumpster fire*

- **Files scanned:** 18
- **Total violations:** 413
- **Top rules triggered:** none

### [rich](https://github.com/Textualize/rich) — 22/100 · *cooked*

- **Files scanned:** 100
- **Total violations:** 1552
- **Top rules triggered:** none

---

